@@ -16,7 +16,9 @@ Usage::
     session_client: RDSDataServiceClient = session.client("rds-data")
     ```
 """
-from mypy_boto3_rds_data.client import RDSDataServiceClient, RDSDataServiceClient as Client
+from mypy_boto3_rds_data.client import RDSDataServiceClient
+
+Client = RDSDataServiceClient
 
 
 __all__ = ("Client", "RDSDataServiceClient")
